==> hoteldruid-mod-fr_2.3.1-1.tar.gz: fr/prenota.php <==
<?php

switch ($messaggio) {

case "Inserisci una nuova prenotazione":  	$messaggio = "Insérer une nouvelle réservation"; break;
case "Cliente titolare":  			$messaggio = "Client titulaire"; break;
case "cognome":  				$messaggio = "nom"; break;
case "nome":  					$messaggio = "prénom"; break;
case "Dal":  					$messaggio = "Du"; break;
case "dal":  					$messaggio = "du"; break;
case "al":  					$messaggio = "au"; break;
case "Tipo di tariffa":  			$messaggio = "Type de tarif"; break;
case "tariffa":  				$messaggio = "tarif"; break;
case "sconto":  				$messaggio = "remise"; break;
case "caparra":  				$messaggio = "arrhes"; break;
case "se diversa dalla normale":  		$messaggio = "si différent de la normale"; break;
case "nº di persone":  				$messaggio = "nombre de personnes"; break;
case "Nº di piano":  				$messaggio = "Numéro de l'étage"; break;
case "e/o di casa":  				$messaggio = "et/ou de maison"; break;
case "e/o di persone":  			$messaggio = "et/ou de personnes"; break;
case "costo aggiuntivo unico":  		$messaggio = "surcoût unique"; break;
case "da moltiplicare per":  			$messaggio = "multiplier par"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "surcoût hebdomadaire"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "surcoût quotidien"; break;
case "nº di settimane da applicare":  		$messaggio = "nombre de semaines à appliquer"; break;
case "nº di giorni da applicare":  		$messaggio = "nombre de jours à appliquer"; break;
case "Commento":  				$messaggio = "Commentaire"; break;
case "Inserisci la prenotazione":  		$messaggio = "Insérer la réservation"; break;
case "Torna al menù principale":  		$messaggio = "Retour au menu principal"; break;
case " o spezzarla":  				$messaggio = " ou en la divisant"; break;
case "Spezza la prenotazione in":  		$messaggio = "Diviser la réservation en"; break;
case "parti":  					$messaggio = "parties"; break;
case "Non é stato possibile dividere la prenotazione a causa del numero di persone":	$messaggio = "Il n'a pas été possible de diviser la réservation en raison du nombre de personnes"; break;
case "Non è possibile inserire la prenotazione senza":	$messaggio = "Il n'est pas possible d'insérer la réservation sans"; break;
case "dividerla":  				$messaggio = "la diviser"; break;
case "in":  					$messaggio = "en"; break;
case "Spezza la prenotazione in":  		$messaggio = "Diviser la réservation en"; break;
case "Non si è potuto inserire la prenotazione a nome di":	$messaggio = "Il n'a pas été possible d'insérer la réservation au nom de"; break;
case "perchè il database è stato modificato nel frattempo":	$messaggio = "parce que la base de données a été modifiée entre-temps"; break;
case "Prenotazione":  				$messaggio = "Réservation"; break;
case "settiman":  				$messaggio = "semaine"; break;
case "giorn":  					$messaggio = "jour"; break;
case "e":  					$messaggio = "et"; break;
case "a":  					$messaggio = "à"; break;
case "o":  					$messaggio = "ou"; break;
case "i":  					$messaggio = "s"; break;
case "a nome di":  				$messaggio = "au nom de"; break;
case "per":  					$messaggio = "pour"; break;
case "persone":  				$messaggio = "personnes"; break;
case "Costo unico":  				$messaggio = "Coût unique"; break;
case "moltiplicato per":  			$messaggio = "multiplié par"; break;
case "Costo settimanale":  			$messaggio = "Coût hebdomadaire"; break;
case "Costo giornaliero":  			$messaggio = "Coût par jour"; break;
case "settimane":  				$messaggio = "semaines"; break;
case "giorni":  				$messaggio = "jours"; break;
case "Caparra":  				$messaggio = "Arrhes"; break;
case "resto da pagare":  			$messaggio = "reste à payer"; break;
case "Commento":  				$messaggio = "Commentaire"; break;
case "inserita":  				$messaggio = "inséré"; break;
case "Modifica la prenotazione":  		$messaggio = "Modifier la réservation"; break;
case "Torna indietro":  			$messaggio = "Retourner"; break;
case "Sconto":  				$messaggio = "Remise"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "Il est nécessaire d'indiquer le nom du client"; break;
case "confermata":  				$messaggio = "confirmé"; break;
case "Confermata":  				$messaggio = "Confirmé"; break;
case "Nº di prenotazioni di questa tipologia":	$messaggio = "Nombre de réservations de ce type"; break;
case "Aggiungi altre tipologie":  		$messaggio = "Ajouter d'autres types"; break;
case "Nessuna nuova prenotazione è stata inserita":	$messaggio = "Aucune nouvelle réservation n'a été insérée"; break;
case "Transazione scaduta":  			$messaggio = "La transaction a expiré"; break;
case "Non si è potuto inserire un costo aggiuntivo della prenotazione a nome di":	$messaggio = "Il n'a pas possible d'insérer un surcoût à la réservation au nom de"; break;
case "Orario stimato di entrata":  		$messaggio = "Heure d'arrivée estimée"; break;
case "giorno":  				$messaggio = "jour"; break;
case "Metodo pagamento caparra":  		$messaggio = "Méthode de paiement des arrhes"; break;
case "Le prenotazioni richieste nel messaggio sono già state inserite":	$messaggio = "Les réservations demandées dans le message ont déjà été insérées"; break;
case "Attenzione":  				$messaggio = "Attention"; break;
case "il prezzo totale delle prenotazioni inserite":	$messaggio = "le prix total des réservations insérées"; break;
case "il prezzo totale delle caparre inserite":	$messaggio = "le montant total des arrhes payées"; break;
case "è diverso da quello contenuto nel messaggio di richiesta di prenotazione":	$messaggio = "est différent de celui contenue dans le message de demande de réservation"; break;
case "Origine":  				$messaggio = "Origine"; break;
case "<b>Attenzione</b>: il prezzo totale":  		$messaggio = "<b>Attention</b>: prix total"; break;
case "non coincide con il prezzo remoto":  	$messaggio = "est différent du prix distant"; break;
case "Modifica come gruppo le prenotazioni inserite":	$messaggio = "Modifier les réservations insérées en tant que groupe"; break;
case "prezzo totale":  				$messaggio = "prix total"; break;
case "prezzo totale giornaliero":  		$messaggio = "prix total par jour"; break;
case "prezzo totale settimanale":  		$messaggio = "prix total par semaine"; break;
case "prezzo tariffa giornaliero":  		$messaggio = "prix tarif par jour"; break;
case "prezzo tariffa settimanale":  		$messaggio = "prix tarif hebdomadaire"; break;
case "% del totale":  				$messaggio = "% du total"; break;
case "% della tariffa":  			$messaggio = "% du tarif"; break;
case "resto commissioni":  			$messaggio = "total commissions déduites"; break;
case "% del prezzo totale":  			$messaggio = "% du prix total"; break;
case "modificata":  				$messaggio = "modifié"; break;
case "Errore":  				$messaggio = "Erreur"; break;
case "costo aggiuntivo":  			$messaggio = "coût supplémentaire"; break;
case "per la prenotazione":  			$messaggio = "pour la réservation"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Tipologia":  				$messaggio = "Type"; break;
case "prezzo tariffa":  			$messaggio = "rate price"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "per un promemoria all'entrata":  		$messaggio = "for a reminder at checkin"; break;
case "per un promemoria all'uscita":  		$messaggio = "for a reminder at checkout"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-fr_3.0.8-1.tar.gz: fr/prenota.php <==
<?php

switch ($messaggio) {

case "Inserisci una nuova prenotazione":  	$messaggio = "Insérer une nouvelle réservation"; break;
case "Cliente titolare":  			$messaggio = "Client titulaire"; break;
case "cognome":  				$messaggio = "nom"; break;
case "nome":  					$messaggio = "prénom"; break;
case "Dal":  					$messaggio = "Du"; break;
case "dal":  					$messaggio = "du"; break;
case "al":  					$messaggio = "au"; break;
case "Tipo di tariffa":  			$messaggio = "Type de tarif"; break;
case "tariffa":  				$messaggio = "tarif"; break;
case "sconto":  				$messaggio = "remise"; break;
case "caparra":  				$messaggio = "arrhes"; break;
case "se diversa dalla normale":  		$messaggio = "si différent de la normale"; break;
case "nº di persone":  				$messaggio = "nombre de personnes"; break;
case "Nº di piano":  				$messaggio = "Numéro de l'étage"; break;
case "e/o di casa":  				$messaggio = "et/ou de maison"; break;
case "e/o di persone":  			$messaggio = "et/ou de personnes"; break;
case "costo aggiuntivo unico":  		$messaggio = "surcoût unique"; break;
case "da moltiplicare per":  			$messaggio = "multiplier par"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "surcoût hebdomadaire"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "surcoût quotidien"; break;
case "nº di settimane da applicare":  		$messaggio = "nombre de semaines à appliquer"; break;
case "nº di giorni da applicare":  		$messaggio = "nombre de jours à appliquer"; break;
case "Commento":  				$messaggio = "Commentaire"; break;
case "Inserisci la prenotazione":  		$messaggio = "Insérer la réservation"; break;
case "Torna al menù principale":  		$messaggio = "Retour au menu principal"; break;
case " o spezzarla":  				$messaggio = " ou en la divisant"; break;
case "Spezza la prenotazione in":  		$messaggio = "Diviser la réservation en"; break;
case "parti":  					$messaggio = "parties"; break;
case "Non é stato possibile dividere la prenotazione a causa del numero di persone":	$messaggio = "Il n'a pas été possible de diviser la réservation en raison du nombre de personnes"; break;
case "Non è possibile inserire la prenotazione senza":	$messaggio = "Il n'est pas possible d'insérer la réservation sans"; break;
case "dividerla":  				$messaggio = "la diviser"; break;
case "in":  					$messaggio = "en"; break;
case "Spezza la prenotazione in":  		$messaggio = "Diviser la réservation en"; break;
case "Non si è potuto inserire la prenotazione a nome di":	$messaggio = "Il n'a pas été possible d'insérer la réservation au nom de"; break;
case "perchè il database è stato modificato nel frattempo":	$messaggio = "parce que la base de données a été modifiée entre-temps"; break;
case "Prenotazione":  				$messaggio = "Réservation"; break;
case "settiman":  				$messaggio = "semaine"; break;
case "giorn":  					$messaggio = "jour"; break;
case "e":  					$messaggio = "et"; break;
case "a":  					$messaggio = "à"; break;
case "o":  					$messaggio = "ou"; break;
case "i":  					$messaggio = "s"; break;
case "a nome di":  				$messaggio = "au nom de"; break;
case "per":  					$messaggio = "pour"; break;
case "persone":  				$messaggio = "personnes"; break;
case "Costo unico":  				$messaggio = "Coût unique"; break;
case "moltiplicato per":  			$messaggio = "multiplié par"; break;
case "Costo settimanale":  			$messaggio = "Coût hebdomadaire"; break;
case "Costo giornaliero":  			$messaggio = "Coût par jour"; break;
case "settimane":  				$messaggio = "semaines"; break;
case "giorni":  				$messaggio = "jours"; break;
case "Caparra":  				$messaggio = "Arrhes"; break;
case "resto da pagare":  			$messaggio = "reste à payer"; break;
case "Commento":  				$messaggio = "Commentaire"; break;
case "inserita":  				$messaggio = "inséré"; break;
case "Modifica la prenotazione":  		$messaggio = "Modifier la réservation"; break;
case "Torna indietro":  			$messaggio = "Retourner"; break;
case "Sconto":  				$messaggio = "Remise"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "Il est nécessaire d'indiquer le nom du client"; break;
case "confermata":  				$messaggio = "confirmé"; break;
case "Confermata":  				$messaggio = "Confirmé"; break;
case "Nº di prenotazioni di questa tipologia":	$messaggio = "Nombre de réservations de ce type"; break;
case "Aggiungi altre tipologie":  		$messaggio = "Ajouter d'autres types"; break;
case "Nessuna nuova prenotazione è stata inserita":	$messaggio = "Aucune nouvelle réservation n'a été insérée"; break;
case "Transazione scaduta":  			$messaggio = "La transaction a expiré"; break;
case "Non si è potuto inserire un costo aggiuntivo della prenotazione a nome di":	$messaggio = "Il n'a pas possible d'insérer un surcoût à la réservation au nom de"; break;
case "Orario stimato di entrata":  		$messaggio = "Heure d'arrivée estimée"; break;
case "giorno":  				$messaggio = "jour"; break;
case "Metodo pagamento caparra":  		$messaggio = "Méthode de paiement des arrhes"; break;
case "Le prenotazioni richieste nel messaggio sono già state inserite":	$messaggio = "Les réservations demandées dans le message ont déjà été insérées"; break;
case "Attenzione":  				$messaggio = "Attention"; break;
case "il prezzo totale delle prenotazioni inserite":	$messaggio = "le prix total des réservations insérées"; break;
case "il prezzo totale delle caparre inserite":	$messaggio = "le montant total des arrhes payées"; break;
case "è diverso da quello contenuto nel messaggio di richiesta di prenotazione":	$messaggio = "est différent de celui contenue dans le message de demande de réservation"; break;
case "Origine":  				$messaggio = "Origine"; break;
case "<b>Attenzione</b>: il prezzo totale":  		$messaggio = "<b>Attention</b>: prix total"; break;
case "non coincide con il prezzo remoto":  	$messaggio = "est différent du prix distant"; break;
case "Modifica come gruppo le prenotazioni inserite":	$messaggio = "Modifier les réservations insérées en tant que groupe"; break;
case "prezzo totale":  				$messaggio = "prix total"; break;
case "prezzo totale giornaliero":  		$messaggio = "prix total par jour"; break;
case "prezzo totale settimanale":  		$messaggio = "prix total par semaine"; break;
case "prezzo tariffa giornaliero":  		$messaggio = "prix tarif par jour"; break;
case "prezzo tariffa settimanale":  		$messaggio = "prix tarif hebdomadaire"; break;
case "% del totale":  				$messaggio = "% du total"; break;
case "% della tariffa":  			$messaggio = "% du tarif"; break;
case "resto commissioni":  			$messaggio = "total commissions déduites"; break;
case "% del prezzo totale":  			$messaggio = "% du prix total"; break;
case "modificata":  				$messaggio = "modifié"; break;
case "Errore":  				$messaggio = "Erreur"; break;
case "costo aggiuntivo":  			$messaggio = "coût supplémentaire"; break;
case "per la prenotazione":  			$messaggio = "pour la réservation"; break;
case "Prenota":  				$messaggio = "Reserve"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Tipologia":  				$messaggio = "Type"; break;
case "OVERBOOKING":  				$messaggio = "OVERBOOKING"; break;
case "prezzo tariffa":  			$messaggio = "rate price"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "per un promemoria all'entrata":  		$messaggio = "for a reminder at checkin"; break;
case "per un promemoria all'uscita":  		$messaggio = "for a reminder at checkout"; break;
case "valuta":  				$messaggio = "currency"; break;
case "Il numero di persone inserite non include i bambini (vedere il commento per il numero di bambini)":	$messaggio = "The inserted number of people does not include children (see comment for the number of children)"; break;
case "da":  					$messaggio = "from"; break;
case "Si è dovuto diminuire il <b>numero di persone</b> per inserire la prenotazione":	$messaggio = "The <b>number of people</b> has been decreased in order to insert the reservation"; break;
case "Prenotazione non inserita":  		$messaggio = "Reservation not inserted"; break;
case "Prenotazione non modificata":  		$messaggio = "Reservation not modified"; break;
case "2° cognome":  				$messaggio = "2nd surname"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
